@@ -1,4 +1,4 @@
-package Affix v1.0.2 {    # 'FFI' is my middle name!
+package Affix v1.0.3 {    # 'FFI' is my middle name!
 
     #~ |-----------------------------------|-----------------------------------||
     #~ |--------------------------4---5~---|--4--------------------------------||
@@ -62,6 +62,9 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
             Pointer Array Struct Union Enum Callback CodeRef Complex Vector
             Packed VarArgs
             SV
+            File PerlIO
+            StringList
+            Buffer SockAddr
             M256 M256d M512 M512d M512i
         ]
     ];
@@ -86,7 +89,7 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
     my $is_bsd = $OS =~ /bsd/;
     my $is_sun = $OS =~ /(solaris|sunos)/;
     #
-    sub locate_libs ( $lib, $version ) {
+    sub locate_libs ( $lib, $version //= () ) {
         $lib =~ s[^lib][];
         my $ver;
         if ( defined $version ) {
@@ -186,7 +189,7 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
         values %store;
     }
 
-    sub locate_lib( $name, $version ) {
+    sub locate_lib( $name, $version //= () ) {
         return $name if $name && -B $name;
         CORE::state $cache //= {};
         return $cache->{$name}{ $version // '' }->{path} if defined $cache->{$name}{ $version // '' };
@@ -359,9 +362,14 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
     sub VarArgs () {';'}
 
     # Semantic aliases and convienient types
-    sub String ()  {'*char'}
-    sub WString () {'*ushort'}
-    sub SV()       {'SV'}
+    sub String ()     {'*char'}
+    sub WString ()    {'*ushort'}
+    sub SV()          {'@SV'}
+    sub File ()       {'@File'}
+    sub PerlIO ()     {'@PerlIO'}
+    sub StringList () {'@StringList'}
+    sub Buffer ()     {'@Buffer'}
+    sub SockAddr ()   {'@SockAddr'}
 
     # Helper for Struct/Union to handle "Name => Type" syntax
     sub _build_aggregate {
@@ -459,7 +467,7 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
                 for my $item (@$elements) {
                     my ( $name, $final_val );
 
-                    # 1. Determine Name and Raw Value Source
+                    # Determine Name and Raw Value Source
                     if ( !ref $item ) {
 
                         # Case: 'NAME' (Auto-increment)
@@ -472,7 +480,7 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
                         my $raw_val;
                         ( $name, $raw_val ) = @$item;
 
-                        # 2. Calculate Value
+                        # Calculate Value
                         if ( $raw_val =~ /^-?\d+$/ ) {
 
                             # Literal Integer
@@ -492,7 +500,7 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
                         Carp::croak("Enum elements must be Strings or [Name => Value] ArrayRefs");
                     }
 
-                    # 3. Store and Increment
+                    # Store and Increment
                     $const_map->{$name} = $final_val;
 
                     # Only map value->name if not already mapped (first name for a value wins in C usually)
@@ -502,29 +510,24 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
                 return ( $const_map, $values_map );
             }
 
-            # A pure-perl expression solver (Shunting-yard algorithm)
-            # Handles: + - * / | & ^ ( )
+            # Shunting-yard algorithm
+            # Handles: + - * / % << >> | & ^ ~ ! ( ) && || == != < <= > >= ? :
             method _calculate_expr( $expr, $lookup ) {
+                use integer;    # Force signed integer arithmetic to match C enums. This ensures ~0 becomes -1, not 18446744073709551615.
 
-                # 1. Tokenize: Split on operators, keep parens and logic ops
-                # Include '%' in the regex
-                my @raw_tokens = split /([+\-*\/%|&^()])/, $expr;
-                my @tokens;
-                foreach my $t (@raw_tokens) {
+                # Tokenize: Split on operators
+                # Regex matches:
+                # - Multi-char ops: << >> && || == != <= >=
+                # - Single-char ops: + - * / % | & ^ ~ ! ( ) ? : < >
+                # - Numbers (hex/dec)
+                # - Identifiers
+                my @tokens = $expr =~ /(0x[0-9a-fA-F]+|\d+|[a-zA-Z_]\w*|<<|>>|&&|\|\||==|!=|<=|>=|[+\-*\/%|&^~!?:()<>])/g;
 
-                    # Skip if undefined or purely whitespace
-                    next unless defined $t && $t =~ /\S/;
-
-                    # Trim leading/trailing whitespace from identifiers
-                    $t =~ s/^\s+|\s+$//g;
-                    push @tokens, $t;
-                }
-
-                # 2. Resolve Identifiers to Numbers
-                foreach my $t (@tokens) {
-                    next if $t =~ /^[+\-*\/%|&^()]$/;    # Skip operators
-                    next if $t =~ /^-?\d+$/;             # Skip integers
-                    next if $t =~ /^0x[0-9a-fA-F]+$/;    # Skip Hex literals
+                # Resolve Identifiers
+                for my $t (@tokens) {
+                    next if $t =~ /^(?:<<|>>|&&|\|\||==|!=|<=|>=|[+\-*\/%|&^~!?:()<>])$/;
+                    next if $t =~ /^\d+$/;
+                    next if $t =~ /^0x/;
                     if ( exists $lookup->{$t} ) {
                         $t = $lookup->{$t};
                     }
@@ -537,64 +540,138 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
                     $t = hex($t) if $t =~ /^0x/;
                 }
 
-                # 3. Shunting-yard: Infix -> RPN (Reverse Polish Notation)
+                # Shunting-yard
                 my @output_queue;
                 my @op_stack;
 
-                # Operator Precedence
+                # Precedence and Associativity (1=Left, 0=Right)
                 my %prec = (
-                    '*' =>  4,
-                    '/' =>  4,
-                    '%' =>  4,
-                    '+' =>  3,
-                    '-' =>  3,
-                    '&' =>  2,
-                    '^' =>  1,
-                    '|' =>  0,
-                    '(' => -1,    # Lowest, handled specially
+                    '*'          => [ 13, 1 ],
+                    '/'          => [ 13, 1 ],
+                    '%'          => [ 13, 1 ],
+                    '+'          => [ 12, 1 ],
+                    '-'          => [ 12, 1 ],
+                    '<<'         => [ 11, 1 ],
+                    '>>'         => [ 11, 1 ],
+                    '<'          => [ 10, 1 ],
+                    '<='         => [ 10, 1 ],
+                    '>'          => [ 10, 1 ],
+                    '>='         => [ 10, 1 ],
+                    '=='         => [ 9,  1 ],
+                    '!='         => [ 9,  1 ],
+                    '&'          => [ 8,  1 ],
+                    '^'          => [ 7,  1 ],
+                    '|'          => [ 6,  1 ],
+                    '&&'         => [ 5,  1 ],
+                    '||'         => [ 4,  1 ],
+                    '?'          => [ 3,  0 ],
+                    ':'          => [ 3,  0 ],                                                                    # Ternary
+                    'unary_plus' => [ 14, 0 ], 'unary_minus' => [ 14, 0 ], '!' => [ 14, 0 ], '~' => [ 14, 0 ],    # Unary
+                    '('          => [ -1, 0 ],
                 );
-                foreach my $token (@tokens) {
-                    if ( $token =~ /^-?\d+$/ ) {
+                my $expect_unary = 1;
+                for my $token (@tokens) {
+                    if ( $token =~ /^\d+$/ ) {
                         push @output_queue, $token;
+                        $expect_unary = 0;
                     }
                     elsif ( $token eq '(' ) {
                         push @op_stack, $token;
+                        $expect_unary = 1;
                     }
                     elsif ( $token eq ')' ) {
                         while ( @op_stack && $op_stack[-1] ne '(' ) {
                             push @output_queue, pop @op_stack;
                         }
                         pop @op_stack;    # Discard '('
+                        $expect_unary = 0;
                     }
-                    elsif ( exists $prec{$token} ) {
-                        while ( @op_stack && defined( $prec{ $op_stack[-1] } ) && $prec{ $op_stack[-1] } >= $prec{$token} ) {
+                    elsif ( $token eq '?' ) {    # Ternary Start
+                        while ( @op_stack && $op_stack[-1] ne '(' && $prec{ $op_stack[-1] }[0] > $prec{$token}[0] ) {
                             push @output_queue, pop @op_stack;
                         }
                         push @op_stack, $token;
+                        $expect_unary = 1;
+                    }
+                    elsif ( $token eq ':' ) {    # Ternary Mid
+                        while ( @op_stack && $op_stack[-1] ne '?' ) {
+                            push @output_queue, pop @op_stack;
+                        }
+
+                        # Don't pop '?' yet, we need it for the final evaluation
+                        $expect_unary = 1;
                     }
                     else {
-                        Carp::croak("Unknown token '$token' in enum expression");
+                        # Handle Unary Operators
+                        if ( $expect_unary && ( $token eq '+' || $token eq '-' || $token eq '!' || $token eq '~' ) ) {
+                            $token = $token eq '+' ? 'unary_plus' : $token eq '-' ? 'unary_minus' : $token;
+                        }
+                        elsif ( !exists $prec{$token} ) {
+                            Carp::croak("Unknown token '$token'");
+                        }
+                        my $p1    = $prec{$token}[0];
+                        my $assoc = $prec{$token}[1];
+                        while (@op_stack) {
+                            my $top = $op_stack[-1];
+                            last if $top eq '(';
+                            my $p2 = $prec{$top}[0];
+                            if ( ( $assoc == 1 && $p1 <= $p2 ) || ( $assoc == 0 && $p1 < $p2 ) ) {
+                                push @output_queue, pop @op_stack;
+                            }
+                            else {
+                                last;
+                            }
+                        }
+                        push @op_stack, $token;
+                        $expect_unary = 1;
                     }
                 }
                 push @output_queue, pop @op_stack while @op_stack;
 
-                # 4. RPN Evaluator
+                # RPN Evaluator
                 my @stack;
-                foreach my $token (@output_queue) {
-                    if ( $token =~ /^-?\d+$/ ) {
+                for my $token (@output_queue) {
+                    if ( $token =~ /^\d+$/ ) {
                         push @stack, $token;
                     }
+                    elsif ( $token eq 'unary_plus' ) {    # No-op
+                    }
+                    elsif ( $token eq 'unary_minus' ) {
+                        push @stack, -( pop @stack );
+                    }
+                    elsif ( $token eq '!' ) {
+                        push @stack, int( !( pop @stack ) );
+                    }
+                    elsif ( $token eq '~' ) {
+                        push @stack, ~( pop @stack );
+                    }
+                    elsif ( $token eq '?' ) {             # Ternary Op: stack is [cond, true_val, false_val]
+                        my $false_val = pop @stack;
+                        my $true_val  = pop @stack;
+                        my $cond      = pop @stack;
+                        push @stack, $cond ? $true_val : $false_val;
+                    }
                     else {
                         my $b = pop @stack;
                         my $a = pop @stack;
-                        if    ( $token eq '+' ) { push @stack, $a + $b; }
-                        elsif ( $token eq '-' ) { push @stack, $a - $b; }
-                        elsif ( $token eq '*' ) { push @stack, $a * $b; }
-                        elsif ( $token eq '/' ) { push @stack, int( $a / $b ); }    # Int div
-                        elsif ( $token eq '%' ) { push @stack, $a % $b; }           # Modulo
-                        elsif ( $token eq '|' ) { push @stack, $a | $b; }
-                        elsif ( $token eq '&' ) { push @stack, $a & $b; }
-                        elsif ( $token eq '^' ) { push @stack, $a ^ $b; }
+                        if    ( $token eq '+' )  { push @stack, $a + $b; }
+                        elsif ( $token eq '-' )  { push @stack, $a - $b; }
+                        elsif ( $token eq '*' )  { push @stack, $a * $b; }
+                        elsif ( $token eq '/' )  { push @stack, int( $a / $b ); }
+                        elsif ( $token eq '%' )  { push @stack, $a % $b; }
+                        elsif ( $token eq '<<' ) { push @stack, $a << $b; }
+                        elsif ( $token eq '>>' ) { push @stack, $a >> $b; }
+                        elsif ( $token eq '|' )  { push @stack, $a | $b; }
+                        elsif ( $token eq '&' )  { push @stack, $a & $b; }
+                        elsif ( $token eq '^' )  { push @stack, $a ^ $b; }
+                        elsif ( $token eq '==' ) { push @stack, int( $a == $b ); }
+                        elsif ( $token eq '!=' ) { push @stack, int( $a != $b ); }
+                        elsif ( $token eq '<' )  { push @stack, int( $a < $b ); }
+                        elsif ( $token eq '<=' ) { push @stack, int( $a <= $b ); }
+                        elsif ( $token eq '>' )  { push @stack, int( $a > $b ); }
+                        elsif ( $token eq '>=' ) { push @stack, int( $a >= $b ); }
+                        elsif ( $token eq '&&' ) { push @stack, int( $a && $b ); }
+                        elsif ( $token eq '||' ) { push @stack, int( $a || $b ); }
                     }
                 }
                 return $stack[0];
@@ -692,337 +769,6 @@ package Affix v1.0.2 {    # 'FFI' is my middle name!
             }
         }
     }
-    {
-        # Demo lib builder
-        class Affix::Compiler v0.12.0 {
-            use Config qw[%Config];
-            use Path::Tiny qw[path tempdir];
-            use File::Spec;
-            use ExtUtils::MakeMaker;
-            #
-            field $os        : param : reader //= $^O;
-            field $cleanup   : param : reader //= 0;
-            field $version   : param : reader //= ();
-            field $build_dir : param : reader //= tempdir( CLEANUP => $cleanup );
-            field $name      : param : reader;
-            field $libname   : reader = $build_dir->child(
-                ( ( $os eq 'MSWin32' || $name =~ /^lib/ ) ? '' : 'lib' ) .
-                    $name . '.' .
-                    $Config{so} .
-                    ( $os eq 'MSWin32' || !defined $version ? '' : '.' . $version )
-            )->absolute;
-            field $platform : reader = ();    # ADJUST
-            field $source   : param : reader;
-            field $flags    : param : reader //= {
-
-                #~ ldflags => $Config{ldflags},
-                cflags   => $Config{cflags},
-                cppflags => $Config{cxxflags}
-            };
-            field @objs : reader = [];
-            ADJUST {
-                $source = [ map { _filemap($_) } @$source ];
-            }
-            #
-            sub _can_run(@cmd) {
-                state $paths //= [ map { $_->realpath } grep { $_->exists } map { path($_) } File::Spec->path ];
-                for my $exe (@cmd) {
-                    grep { return path($_) if $_ = MM->maybe_command($_) } $exe, map { $_->child($exe) } @$paths;
-                }
-            }
-            #
-            field $linker : reader : param //= _can_run qw[g++ ld];
-
-            #~ https://gcc.gnu.org/onlinedocs/gcc-3.4.0/gnat_ug_unx/Creating-an-Ada-Library.html
-            field $ada : reader : param //= _can_run qw[gnatmake];
-
-            #~ https://fasterthanli.me/series/making-our-own-executable-packer/part-5
-            #~ https://stackoverflow.com/questions/71704813/writing-and-linking-shared-libraries-in-assembly-32-bit
-            #~ https://github.com/therealdreg/nasm_linux_x86_64_pure_sharedlib
-            field $asm : reader : param //= _can_run qw[nasm as];
-            field $c   : reader : param //= _can_run qw[gcc clang cc icc icpx cl eccp];
-            field $cpp : reader : param //= _can_run qw[g++ clang++ c++ icpc icpx cl eccp];
-
-            #~ https://c3-lang.org/build-your-project/build-commands/
-            field $c3 : reader : param //= _can_run qw[c3c];
-
-            #~ https://www.circle-lang.org/site/index.html
-            field $circle : reader : param //= _can_run qw[circle];
-
-            #~ https://mazeez.dev/posts/writing-native-libraries-in-csharp
-            #~ https://medium.com/@sixpeteunder/how-to-build-a-shared-library-in-c-sharp-and-call-it-from-java-code-6931260d01e5
-            field $csharp : reader : param //= _can_run qw[dotnet];
-
-            # cobc: https://gnucobol.sourceforge.io/
-            field $cobol : reader : param //= _can_run qw[cobc cobol cob cob2];
-
-            #~ https://github.com/crystal-lang/crystal/issues/921#issuecomment-2413541412
-            field $crystal : reader : param //= _can_run qw[crystal];
-
-            #~ https://wiki.liberty-eiffel.org/index.php/Compile
-            #~ https://svn.eiffel.com/eiffelstudio-public/branches/Eiffel_54/Delivery/docs/papers/dll.html
-            field $eiffel : reader : param //= _can_run qw[se];
-
-            #~ https://dlang.org/articles/dll-linux.html#dso9
-            #~ dmd -c dll.d -fPIC
-            #~ dmd -oflibdll.so dll.o -shared -defaultlib=libphobos2.so -L-rpath=/path/to/where/shared/library/is
-            field $d       : reader : param //= _can_run qw[dmd];
-            field $fortran : reader : param //= _can_run qw[gfortran ifx ifort];
-
-            #~ https://github.com/secana/Native-FSharp-Library
-            #~ https://secanablog.wordpress.com/2020/02/01/writing-a-native-library-in-f-which-can-be-called-from-c/
-            field $fsharp : reader : param //= _can_run qw[dotnet];
-
-            #~ https://futhark.readthedocs.io/en/stable/usage.html
-            field $futhark : reader : param //= _can_run qw[futhark];    # .fut => .c
-
-            #~ https://medium.com/@walkert/fun-building-shared-libraries-in-go-639500a6a669
-            #~ https://github.com/vladimirvivien/go-cshared-examples
-            field $go : reader : param //= _can_run qw[go];
-
-            #~ https://github.com/bennoleslie/haskell-shared-example
-            #~ https://www.hobson.space/posts/haskell-foreign-library/
-            field $haskell : reader : param //= _can_run qw[ghc cabal];
-
-            #~ https://peterme.net/dynamic-libraries-in-nim.html
-            field $nim : reader : param //= _can_run qw[nim];    # .nim => .c
-
-            #~ https://odin-lang.org/news/calling-odin-from-python/
-            field $odin : reader : param //= _can_run qw[odin];
-
-            #~ https://p-org.github.io/P/getstarted/install/#step-4-recommended-ide-optional
-            #~ https://p-org.github.io/P/getstarted/usingP/#compiling-a-p-program
-            field $p : reader : param //= _can_run qw[p];    # .p => C#
-
-            #~ https://blog.asleson.org/2021/02/23/how-to-writing-a-c-shared-library-in-rust/
-            field $rust : reader : param //= _can_run qw[cargo];
-
-            #~ swiftc point.swift -emit-module -emit-library
-            #~ https://forums.swift.org/t/creating-a-c-accessible-shared-library-in-swift/45329/5
-            #~ https://theswiftdev.com/building-static-and-dynamic-swift-libraries-using-the-swift-compiler/#should-i-choose-dynamic-or-static-linking
-            field $swift : reader : param //= _can_run qw[swiftc];
-
-            #~ https://www.rangakrish.com/index.php/2023/04/02/building-v-language-dll/
-            #~ https://dev.to/piterweb/how-to-create-and-use-dlls-on-vlang-1p13
-            field $v : reader : param //= _can_run qw[v];
-
-            #~ https://ziglang.org/documentation/0.13.0/#Exporting-a-C-Library
-            #~ zig build-lib mathtest.zig -dynamic
-            field $zig : reader : param //= _can_run qw[zig];
-            #
-            ADJUST {
-            }
-
-            sub _filemap( $file, $language //= () ) {
-                #
-                ($_) = $file =~ m[\.(?=[^.]*\z)([^.]+)\z]i;
-                $language //=                                                     #
-                    /^(?:ada|adb|ads|ali)$/i                  ? 'Ada' :           #
-                    /^(?:asm|s|a)$/i                          ? 'Assembly' :      #
-                    /^(?:c(?:c|pp|xx))$/i                     ? 'CPP' :           #
-                    /^c$/i                                    ? 'C' :             #
-                    /^c3$/i                                   ? 'C3' :            #
-                    /^d$/i                                    ? 'D' :             #
-                    /^cobol$/i                                ? 'Cobol' :         #
-                    /^csharp$/i                               ? 'CSharp' :        #
-                    /^crystal$/i                              ? 'Crystal' :       #
-                    /^futhark$/i                              ? 'Futhark' :       #
-                    /^go$/i                                   ? 'Go' :            #
-                    /^haskell$/i                              ? 'Haskell' :       #
-                    /^nim$/i                                  ? 'Nim' :           #
-                    /^odin$/i                                 ? 'Odin' :          #
-                    /^ace$/i                                  ? 'Eiffel' :        #
-                    /^(?:f(?:or)?|f(?:77|90|95|0[38]|18)?)$/i ? 'Fortran' :       #
-                    /^m+$/i                                   ? 'ObjectiveC' :    #
-                    /^p$/i                                    ? 'P' :             #
-                    /^v$/i                                    ? 'VLang' :         #
-                    ();
-                ( 'Affix::Compiler::File::' . ${language} )->new( path => $file );
-            }
-            #
-            method compile() {
-                @objs = map { path($_) } grep {defined} map { $_->compile($flags) } @$source;
-            }
-
-            method link() {
-                @objs || $self->compile;
-
-                #~ use Data::Dump;
-                #~ ddx\@objs;
-                return () unless grep { $_->exists } @objs;
-                system( $linker, $flags->{ldflags} // (), '-shared', '-o', $libname->stringify, ( map { $_->absolute->stringify } @objs ) ) ? () :
-                    $libname;
-            }
-
-            #~ field $cxx;
-            #~ field $d;
-            #~ field $crystal;
-        };
-
-        class Affix::Compiler::File {
-            use Config     qw[%Config];
-            use Path::Tiny qw[];
-            field $path  : reader : param;
-            field $flags : reader : param //= ();
-            field $obj   : reader : param //= ();
-            ADJUST {
-                $path = Path::Tiny::path($path) unless builtin::blessed $path;
-                $obj //= $path->sibling( $path->basename(qr/\..+?$/) . $Config{_o} );
-            }
-            method compile() {...}
-        }
-
-        class Affix::Compiler::File::CPP : isa(Affix::Compiler::File) {
-
-            # https://learn.microsoft.com/en-us/cpp
-            # https://gcc.gnu.org/
-            # https://clang.llvm.org/
-            #~ https://www.intel.com/content/www/us/en/developer/tools/oneapi/dpc-compiler.html
-            #~ https://www.ibm.com/products/c-and-c-plus-plus-compiler-family
-            #~ https://docs.oracle.com/cd/E37069_01/html/E37073/gkobs.html
-            #~ https://www.edg.com/c
-            #~ https://www.circle-lang.org/site/index.html
-            field $compiler : reader : param //= Affix::Compiler::_can_run qw[g++]
-
-                #~ clang++ cl icpx ibm-clang++ CC eccp circle]
-                ;
-
-            method compile($flags) {
-                system( $compiler, '-g', '-c', '-fPIC', $flags->{cxxflags} // (), $self->path, '-o', $self->obj ) ? () : $self->obj;
-            }
-        }
-
-        class Affix::Compiler::File::C : isa(Affix::Compiler::File) {
-            use Config qw[%Config];
-            field $compiler : reader : param //= Affix::Compiler::_can_run $Config{cc}, qw[gcc]
-
-                #~ clang cl icx ibm-clang CC eccp circle]
-                ;
-
-            method compile($flags) {
-                system( $compiler, '-g', '-c', '-Wall', '-fPIC', $flags->{cflags} // (), $self->path, '-o', $self->obj ) ? () : $self->obj;
-            }
-        }
-
-        class Affix::Compiler::File::Fortran : isa(Affix::Compiler::File) {
-
-            # GNU, Intel, Intel Classic
-            my $compiler = Affix::Compiler::_can_run qw[gfortran ifx ifort];
-
-            method compile($flags) {
-                my $obj = $self->obj;
-                my $src = $self->path;
-                warn qq`gfortran -shared -o $obj $src`;
-                `gfortran -shared -o $obj $src`;
-                $obj;
-
-             #~ $self->obj
-             #~ unless system grep {defined} $compiler, '-shared', ( Affix::Platform::Windows() ? () : '-fPIC' ), $flags->{fflags} // (), $self->path,
-             #~ '-o', $self->obj;
-            }
-        }
-
-        class Affix::Compiler::File::D : isa(Affix::Compiler::File) {
-            use Config qw[%Config];
-            field $compiler : reader : param //= Affix::Compiler::_can_run qw[dmd];
-
-            method compile($flags) {
-                system( $compiler, '-c', ( Affix::Platform::Windows() ? () : '-fPIC' ), $flags->{dflags} // (), $self->path, '-of=' . $self->obj ) ?
-                    () : $self->obj;
-            }
-        }
-
-        class Affix::Compiler::FortranXXXXXX : isa(Affix::Compiler) {
-            use Config     qw[%Config];
-            use IPC::Cmd   qw[can_run];
-            use Path::Tiny qw[path];
-            field $exe      : reader;
-            field $compiler : reader;
-            field $linker   : reader;
-            #
-            ADJUST {
-                if ( $exe = can_run('gfortran') ) {
-                    $compiler = method( $file, $obj, $flags ) {
-                        system $self->exe, qw[-c -fPIC], $file;
-                        die "failed to execute: $!\n"                                                                           if $? == -1;
-                        die sprintf "child died with signal %d, %s coredump\n", ( $? & 127 ), ( $? & 128 ) ? 'with' : 'without' if $? & 127;
-                        $obj
-                    };
-                    $linker = method($objs) {
-                        system $self->exe, qw[-shared], ( map { $_->stringify } @$objs ), '-o blah.so';
-                        die "failed to execute: $!\n"                                                                           if $? == -1;
-                        die sprintf "child died with signal %d, %s coredump\n", ( $? & 127 ), ( $? & 128 ) ? 'with' : 'without' if $? & 127;
-                        'ok!'
-                    };
-                }
-                elsif ( $exe = can_run('ifx') )   { }
-                elsif ( $exe = can_run('ifort') ) { }
-            }
-            #
-            method compile( $file, $obj //= (), $flags //= '' ) {
-                $file = path($file)->absolute unless builtin::blessed $file;
-                $obj //= $file->sibling( $file->basename(qr/\..+?$/) . $Config{_o} );
-                try {
-                    return $compiler->( $self, $file, $obj, $flags );
-                }
-                catch ($err) { warn $err; }
-            }
-
-            method link($objs) {
-                $objs = [ map { builtin::blessed $_ ? $_ : path($_)->absolute } @$objs ];
-                return () unless @$objs;
-                try {
-                    return $linker->( $self, $objs );
-                }
-                catch ($err) { warn $err; }
-            }
-        }
-
-        class Affix::Compiler::File::Dxxx : isa(Affix::Compiler) {
-            use Config     qw[%Config];
-            use IPC::Cmd   qw[can_run];
-            use Path::Tiny qw[];
-            field $exe      : reader;
-            field $compiler : reader;
-            field $linker   : reader;
-            field $path     : reader : param;
-            #
-            ADJUST {
-                if ( $exe = can_run('dmd') ) {
-                    $compiler = method( $file, $obj, $flags ) {
-                        system $self->exe, qw[-c -fPIC], $file->stringify;
-                        die "failed to execute: $!\n"                                                                           if $? == -1;
-                        die sprintf "child died with signal %d, %s coredump\n", ( $? & 127 ), ( $? & 128 ) ? 'with' : 'without' if $? & 127;
-                        $obj
-                    };
-                    $linker = method($objs) {
-                        system $self->exe, qw[-shared], ( map { $_->stringify } @$objs ), '-o blah.so';
-                        die "failed to execute: $!\n"                                                                           if $? == -1;
-                        die sprintf "child died with signal %d, %s coredump\n", ( $? & 127 ), ( $? & 128 ) ? 'with' : 'without' if $? & 127;
-                        'ok!'
-                    };
-                }
-            }
-            #
-            method compile( $file, $obj //= (), $flags //= '' ) {
-                $file = Path::Tiny::path($file)->absolute unless builtin::blessed $file;
-                $obj //= $file->sibling( $file->basename(qr/\..+?$/) . $Config{_o} );
-                try {
-                    return $compiler->( $self, $file->stringify, $obj, $flags );
-                }
-                catch ($err) { warn $err; }
-            }
-
-            method link($objs) {
-                $objs = [ map { builtin::blessed $_ ? $_ : Path::Tiny::path($_)->absolute } @$objs ];
-                return () unless @$objs;
-                try {
-                    return $linker->( $self, $objs );
-                }
-                catch ($err) { warn $err; }
-            }
-        }
-    }
 }
 1;
 __END__
